@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher;
-BEGIN {
-  $WWW::FetchStory::Fetcher::VERSION = '0.1601';
+{
+  $WWW::FetchStory::Fetcher::VERSION = '0.17';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1601
+version 0.17
 
 =head1 DESCRIPTION
 
@@ -76,6 +76,10 @@ sub init {
 	{
 	    $self->{wget_cmd} .= " --debug";
 	}
+	if ($self->{wget_options})
+	{
+	    $self->{wget_cmd} .= ' ' . $self->{wget_options};
+	}
     }
     else
     {
@@ -219,6 +223,10 @@ Fetch the story, with the given options.
 Optional basename used to construct the filenames.
 If this is not given, the basename is derived from the title of the story.
 
+=item epub
+
+Create an EPUB file, deleting the HTML files which have been downloaded.
+
 =item toc
 
 Build a table-of-contents file if this is true.
@@ -251,50 +259,64 @@ sub fetch {
     my %story_info = $self->parse_toc(content=>$toc_content,
 	url=>$args{url});
 
-    my @ch_urls = @{$story_info{chapters}};
-    my $one_chapter = (@ch_urls == 1);
-    my $first_chapter_is_toc = $story_info{toc_first};
     my $basename = ($args{basename}
 		    ? $args{basename}
 		    : $self->get_story_basename($story_info{title}));
     $story_info{basename} = $basename;
     my @storyfiles = ();
-    my @ch_titles = ();
-    my @ch_wc = ();
-    my $count = (($one_chapter or $first_chapter_is_toc) ? 0 : 1);
-    foreach (my $i = 0; $i < @ch_urls; $i++)
-    {
-	my $ch_title = sprintf("%s (%d)", $story_info{title}, $i+1);
-	my %ch_info = $self->get_chapter(base=>$basename,
-				    count=>$count,
-				    url=>$ch_urls[$i],
-				    title=>$ch_title);
-	push @storyfiles, $ch_info{filename};
-	push @ch_titles, $ch_info{title};
-	push @ch_wc, $ch_info{wordcount};
-	$story_info{wordcount} += $ch_info{wordcount};
-	$count++;
-	sleep 1; # try not to overload the archive
-    }
-    $self->derive_values(info=>\%story_info);
 
-    warn Dump(\%story_info) if $self->{verbose};
+    if ($args{epub} and exists $story_info{epub_url} and $story_info{epub_url})
+    {
+	my %epub_info = $self->get_epub(base=>$basename,
+	    url=>$story_info{epub_url},
+	    title=>$story_info{title});
+	$story_info{storyfiles} = [$epub_info{filename}];
 
-    $story_info{storyfiles} = \@storyfiles;
-    $story_info{chapter_titles} = \@ch_titles;
-    $story_info{chapter_wc} = \@ch_wc;
-    if ($args{toc} and !$args{epub}) # build a table-of-contents
-    {
-	my $toc = $self->build_toc(info=>\%story_info);
-	unshift @{$story_info{storyfiles}}, $toc;
-	unshift @{$story_info{chapter_titles}}, "Table of Contents";
+	$self->derive_values(info=>\%story_info);
+	warn Dump(\%story_info) if $self->{verbose};
     }
-    if ($args{epub})
+    else
     {
-	my $epub_file = $self->build_epub(info=>\%story_info);
-	# if we have built an EPUB file, then the storyfiles
-	# are now just one EPUB file.
-	$story_info{storyfiles} = [$epub_file];
+	my @ch_urls = @{$story_info{chapters}};
+	my $one_chapter = (@ch_urls == 1);
+	my $first_chapter_is_toc = $story_info{toc_first};
+	my @ch_titles = ();
+	my @ch_wc = ();
+	my $count = (($one_chapter or $first_chapter_is_toc) ? 0 : 1);
+	foreach (my $i = 0; $i < @ch_urls; $i++)
+	{
+	    my $ch_title = sprintf("%s (%d)", $story_info{title}, $i+1);
+	    my %ch_info = $self->get_chapter(base=>$basename,
+		count=>$count,
+		url=>$ch_urls[$i],
+		title=>$ch_title);
+	    push @storyfiles, $ch_info{filename};
+	    push @ch_titles, $ch_info{title};
+	    push @ch_wc, $ch_info{wordcount};
+	    $story_info{wordcount} += $ch_info{wordcount};
+	    $count++;
+	    sleep 1; # try not to overload the archive
+	}
+	$self->derive_values(info=>\%story_info);
+
+	warn Dump(\%story_info) if $self->{verbose};
+
+	$story_info{storyfiles} = \@storyfiles;
+	$story_info{chapter_titles} = \@ch_titles;
+	$story_info{chapter_wc} = \@ch_wc;
+	if ($args{toc} and !$args{epub}) # build a table-of-contents
+	{
+	    my $toc = $self->build_toc(info=>\%story_info);
+	    unshift @{$story_info{storyfiles}}, $toc;
+	    unshift @{$story_info{chapter_titles}}, "Table of Contents";
+	}
+	if ($args{epub})
+	{
+	    my $epub_file = $self->build_epub(info=>\%story_info);
+	    # if we have built an EPUB file, then the storyfiles
+	    # are now just one EPUB file.
+	    $story_info{storyfiles} = [$epub_file];
+	}
     }
     if ($args{yaml})
     {
@@ -577,6 +599,7 @@ sub parse_toc {
     $info{category} = $self->parse_category(%args);
     $info{rating} = $self->parse_rating(%args);
     $info{chapters} = $self->parse_chapter_urls(%args);
+    $info{epub_url} = $self->parse_epub_url(%args);
 
     return %info;
 } # parse_toc
@@ -598,6 +621,22 @@ sub parse_chapter_urls {
     return \@chapters;
 } # parse_chapter_urls
 
+=head2 parse_epub_url
+
+Figure out the URL for the EPUB version of this story, if there is one.
+
+=cut
+sub parse_epub_url {
+    my $self = shift;
+    my %args = (
+	url=>'',
+	content=>'',
+	@_
+    );
+
+    return undef;
+} # parse_epub_url
+
 =head2 parse_title
 
 Get the title from the content
@@ -820,6 +859,32 @@ sub parse_universe {
     return $universe;
 } # parse_universe
 
+=head2 parse_recipient
+
+Get the recipient from the content
+
+=cut
+sub parse_recipient {
+    my $self = shift;
+    my %args = (
+	url=>'',
+	content=>'',
+	@_
+    );
+
+    my $content = $args{content};
+    my $recipient = '';
+    if ($content =~ m#Recipient: (\w+)#is)
+    {
+	$recipient = $1;
+    }
+    elsif ($content =~ m#Recipient:</(?:b|strong|u)>([^<]+)#is)
+    {
+	$recipient = $1;
+    }
+    return $recipient;
+} # parse_recipient
+
 =head2 parse_category
 
 Get the categories from the content
@@ -976,6 +1041,42 @@ sub get_chapter {
 	);
 } # get_chapter
 
+=head2 get_epub
+
+Get the EPUB version of the story, tidy it,
+and save it to a file.
+
+    $filename = $obj->get_epub(base=>$basename,
+				    url=>$url);
+
+=cut
+
+sub get_epub {
+    my $self = shift;
+    my %args = (
+	base=>'',
+	count=>0,
+	url=>'',
+	title=>'',
+	@_
+    );
+
+    my $content = $self->get_page($args{url});
+
+    #
+    # Write the file
+    #
+    my $filename = $args{base} . '.epub';
+    my $ofh;
+    open($ofh, ">",  $filename) || die "Can't write to $filename";
+    print $ofh $content;
+    close($ofh);
+
+    return (
+	filename=>$filename,
+	);
+} # get_epub
+
 =head2 wordcount
 
 Figure out the word-count.
@@ -1303,4 +1404,4 @@ sub tidy_chars {
 } # tidy_chars
 
 1; # End of WWW::FetchStory::Fetcher
-__END__
\ No newline at end of file
+__END__
