@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::AO3;
-BEGIN {
-  $WWW::FetchStory::Fetcher::AO3::VERSION = '0.1601';
+{
+  $WWW::FetchStory::Fetcher::AO3::VERSION = '0.17';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::AO3 - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1601
+version 0.17
 
 =head1 DESCRIPTION
 
@@ -79,7 +79,7 @@ sub allow {
     my $self = shift;
     my $url = shift;
 
-    return ($url =~ /archiveofourown\.org$/ || $url =~ /ao3\.org$/);
+    return ($url =~ /archiveofourown\.org/ || $url =~ /ao3\.org/);
 } # allow
 
 =head1 Private Methods
@@ -141,6 +141,7 @@ sub parse_toc {
     $info{category} = $self->parse_category(%args);
     $info{rating} = $self->parse_rating(%args);
     $info{chapters} = $self->parse_chapter_urls(%args, sid=>$sid);
+    $info{epub_url} = $self->parse_epub_url(%args, sid=>$sid);
 
     return %info;
 } # parse_toc
@@ -168,6 +169,29 @@ sub parse_chapter_urls {
     return \@chapters;
 } # parse_chapter_urls
 
+=head2 parse_epub_url
+
+Figure out the URL for the EPUB version of this story.
+
+=cut
+sub parse_epub_url {
+    my $self = shift;
+    my %args = (
+	url=>'',
+	content=>'',
+	@_
+    );
+    my $content = $args{content};
+    my $sid = $args{sid};
+    my $epub_url = '';
+    if ($content =~ m!href="(/downloads/\w+/$sid/[^.]+\.epub)"!)
+    {
+	$epub_url = ("http://archiveofourown.org$1");
+    }
+
+    return $epub_url;
+} # parse_epub_url
+
 =head2 parse_title
 
 Get the title.
@@ -335,4 +359,4 @@ sub parse_category {
 } # parse_category
 
 1; # End of WWW::FetchStory::Fetcher::AO3
-__END__
\ No newline at end of file
+__END__
