@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::Ashwinder;
-BEGIN {
-  $WWW::FetchStory::Fetcher::Ashwinder::VERSION = '0.1601';
+{
+  $WWW::FetchStory::Fetcher::Ashwinder::VERSION = '0.17';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::Ashwinder - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1601
+version 0.17
 
 =head1 DESCRIPTION
 
@@ -173,14 +173,16 @@ sub parse_chapter_urls {
     my @chapters = ();
     # Ashwinder does not have a sane chapter system
     my $fmt = 'http://ashwinder.sycophanthex.com/viewstory.php?action=printable&sid=%d';
-    if ($content =~ m#&i=1"#s)
+    if ($content =~ m#i=1"#s)
     {
-	while ($content =~ m#<a href="viewstory.php\?sid=(\d+)&i=1">#sg)
+	my $count = 1;
+	while ($content =~ m#viewstory\.php\?sid=(\d+)#sg)
 	{
 	    my $ch_sid = $1;
 	    my $ch_url = sprintf($fmt, $ch_sid);
-	    warn "chapter=$ch_url\n" if $self->{verbose};
+	    warn "chapter[$count]=$ch_url\n" if $self->{verbose};
 	    push @chapters, $ch_url;
+	    $count++;
 	}
     }
     else
@@ -244,4 +246,4 @@ sub parse_author {
 } # parse_author
 
 1; # End of WWW::FetchStory::Fetcher::Ashwinder
-__END__
\ No newline at end of file
+__END__
